summaryrefslogtreecommitdiffstats
path: root/kdeui/kbuttonbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/kbuttonbox.h')
-rw-r--r--kdeui/kbuttonbox.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdeui/kbuttonbox.h b/kdeui/kbuttonbox.h
index 7eda45577..0d4b36b67 100644
--- a/kdeui/kbuttonbox.h
+++ b/kdeui/kbuttonbox.h
@@ -30,9 +30,9 @@ class KButtonBoxPrivate;
/**
* Container widget for buttons.
*
* This class uses Qt layout control to place the buttons; can handle
* both vertical and horizontal button placement. The default border
- * is now @p 0 (making it easier to deal with layouts). The space
+ * is now @p 0 (making it easier to deal with tqlayouts). The space
* between buttons is now more Motif compliant.
*
* @author Mario Weilguni <mweilguni@sime.com>
@@ -65,7 +65,7 @@ public:
* This size is
* calculated by the width/height of all buttons plus border/autoborder.
*/
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
virtual TQSizePolicy sizePolicy() const;
virtual void resizeEvent(TQResizeEvent *);
@@ -146,9 +146,9 @@ public:
* This function must be called @em once after all buttons have been
* inserted.
*
* It will start layout control.
*/
- void layout();
+ void tqlayout();
public: // as PrivateData needs Item, it has to be exported
class Item;
@@ -30,9 +30,9 @@ class KButtonBoxPrivate;
* Container widget for buttons.
*
- * This class uses Qt layout control to place the buttons; can handle
+ * This class uses Qt tqlayout control to place the buttons; can handle
* both vertical and horizontal button placement. The default border
@@ -146,9 +146,9 @@ public:
* inserted.
*
- * It will start layout control.
+ * It will start tqlayout control.
*/